==> exo-clouddrive-cmis-services-1.3.1-sources.jar: org/exoplatform/clouddrive/cmis/CMISInvalidArgumentException.java <==

/*
 * Copyright (C) 2003-2014 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.exoplatform.clouddrive.cmis;

import org.apache.chemistry.opencmis.commons.exceptions.CmisInvalidArgumentException;

/**
 * Wrong argument in a request to CMIS service. Created to warp {@link CmisInvalidArgumentException}.<br>
 * 
 * Created by The eXo Platform SAS
 * 
 * @author <a href="mailto:pnedonosko@exoplatform.com">Peter Nedonosko</a>
 * @version $Id: CMISInvalidArgumentException.java 00000 Nov 5, 2014 pnedonosko $
 * 
 */
public class CMISInvalidArgumentException extends CMISException {

  /**
   * @param message
   * @param cause
   */
  public CMISInvalidArgumentException(String message, Throwable cause) {
    super(message, cause);
  }

}

==> exo-clouddrive-cmis-services-1.5.1-sources.jar: org/exoplatform/clouddrive/cmis/CMISInvalidArgumentException.java <==

/*
 * Copyright (C) 2003-2016 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.exoplatform.clouddrive.cmis;

import org.apache.chemistry.opencmis.commons.exceptions.CmisInvalidArgumentException;

/**
 * Wrong argument in a request to CMIS service. Created to warp
 * {@link CmisInvalidArgumentException}.<br>
 * Created by The eXo Platform SAS
 * 
 * @author <a href="mailto:pnedonosko@exoplatform.com">Peter Nedonosko</a>
 * @version $Id: CMISInvalidArgumentException.java 00000 Nov 5, 2014 pnedonosko
 *          $
 */
public class CMISInvalidArgumentException extends CMISException {

  /**
   * Instantiates a new CMIS invalid argument exception.
   *
   * @param message the message
   * @param cause the cause
   */
  public CMISInvalidArgumentException(String message, Throwable cause) {
    super(message, cause);
  }

}
